@@ -259,6 +259,7 @@ void KitaBoardView::UpdateKindLabel()
 void KitaBoardView::setFont( const QFont& font )
 {
     subjectList->setFont( font );
+    SearchCombo->setFont( font );
 }
 
 void KitaBoardView::slotUpdateSubject( const KURL& url )
@@ -436,7 +437,6 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
             propertyWidget->idx_readNumLabel->setText( QString( "%1" ).arg( Kita::ThreadIndex::getReadNum( datURL ) ) );
             propertyWidget->idx_viewPosLabel->setText( QString( "%1" ).arg( Kita::ThreadIndex::getViewPos( datURL ) ) );
 
-            propertyWidget->cache_resNumLabel->setText( QString( "%1" ).arg( KitaThreadInfo::resNum( datURL ) ) );
             propertyWidget->cache_readNumLabel->setText( QString( "%1" ).arg( KitaThreadInfo::readNum( datURL ) ) );
             propertyWidget->show();
         }
