@@ -47,7 +47,8 @@ namespace Kita
         void insertSearchCombo();
         QStringList parseSearchQuery( const QString& input );
         void searchNext( const QStringList& input );
-        void searchAll( const QStringList& query );
+        void searchNew( const QStringList& query );
+        void clearSearch();
         void hideColumn( int col );
         void showColumn( int col );
 
