@@ -815,98 +815,22 @@ void Kita::parseName( const QString& rawStr, RESDAT& resdat )
 */
 void Kita::parseDateId( const QString& rawStr, RESDAT& resdat )
 {
-    if ( m_weekstr[ 0 ] == QString::null ) {
-        m_weekstr[ 0 ] = utf8ToUnicode( KITAUTF8_MONDAY );
-        m_weekstr[ 1 ] = utf8ToUnicode( KITAUTF8_TUESDAY );
-        m_weekstr[ 2 ] = utf8ToUnicode( KITAUTF8_WEDNESDAY );
-        m_weekstr[ 3 ] = utf8ToUnicode( KITAUTF8_THURSDAY );
-        m_weekstr[ 4 ] = utf8ToUnicode( KITAUTF8_FRIDAY );
-        m_weekstr[ 5 ] = utf8ToUnicode( KITAUTF8_SATURDAY );
-        m_weekstr[ 6 ] = utf8ToUnicode( KITAUTF8_SUNDAY );
-    }
-
     resdat.date = rawStr;
     resdat.id = QString::null;
     resdat.host = QString::null;
+    resdat.be = QString::null;
+    resdat.bepointmark = QString::null;
 
     const QChar *chpt = rawStr.unicode();
     unsigned int pos = 0, startpos = 0;
     unsigned int length = rawStr.length();
 
-    /* year */
-    while ( chpt[ pos ] != '/' && pos++ < length );
-    if ( pos >= length ) return ;
-    int year = rawStr.mid( 0, pos ).toInt();
-    pos++;
-
-    if ( year >= 70 && year < 100 ) {
-        year += 1900;
-    } else if ( year < 70 ) {
-        year += 2000;
-    }
-
-    //    qDebug("year %d, pos %d",year,pos );
-
-    /* month */
-    startpos = pos;
-    while ( chpt[ pos ] != '/' && pos++ < length );
-    if ( pos >= length ) return ;
-    int month = rawStr.mid( startpos, pos - startpos ).toInt();
-    pos++;
-
-    //    qDebug("month %d, pos %d",month,pos );
-
-    /* day */
-    startpos = pos;
-    while ( chpt[ pos ] != ' ' && chpt[ pos ] != '(' && pos++ < length );
-    if ( pos >= length ) return ;
-    int day = rawStr.mid( startpos, pos - startpos ).toInt();
-    pos++;
-
-    //    qDebug("day %d, pos %d",day,pos );
-
-    /* skip week */
-    if ( chpt[ pos - 1 ] == '(' ) {
-
-        while ( chpt[ pos ] != ')' && pos++ < length );
+    while ( chpt[ pos ] != '\0' &&
+            !( chpt[ pos ] == 'I' && chpt[ pos + 1 ] == 'D' ) &&
+            !( chpt[ pos ] == 'B' && chpt[ pos + 1 ] == 'E' ) ) {
         pos++;
     }
-
-    /* hour */
-    startpos = pos;
-    while ( chpt[ pos ] != ':' && pos++ < length );
-    if ( pos >= length ) return ;
-    int hour = rawStr.mid( startpos, pos - startpos ).toInt();
-    pos++;
-
-    //    qDebug("h %d, pos %d",hour,pos );
-
-    /* min */
-    startpos = pos;
-    while ( chpt[ pos ] != ':' && chpt[ pos ] != ' ' && pos++ < length );
-    int min = rawStr.mid( startpos, pos - startpos ).toInt();
-    pos++;
-
-    //    qDebug("min %d, pos %d",min,pos );
-
-    /* sec */
-    int sec = 0;
-    if ( pos < length && chpt[ pos - 1 ] == ':' ) {
-        startpos = pos;
-        while ( chpt[ pos ] != ' ' && pos++ < length );
-        sec = rawStr.mid( startpos, pos - startpos ).toInt();
-        pos++;
-
-        //	qDebug("sec %d, pos %d",sec,pos );
-    }
-
-    /* date */
-    resdat.dateTime = QDateTime( QDate( year, month, day ), QTime( hour, min, sec ) );
-    resdat.date = resdat.dateTime.toString( "yy/MM/dd" )
-                  + m_weekstr[ resdat.dateTime.date().dayOfWeek() - 1 ]
-                  + resdat.dateTime.toString( "hh:mm:ss" );
-
-    if ( pos >= length ) return ;
+    resdat.date = rawStr.left( pos );
 
     /* id */
     if ( chpt[ pos ] == 'I' && chpt[ pos + 1 ] == 'D' ) {
@@ -921,6 +845,22 @@ void Kita::parseDateId( const QString& rawStr, RESDAT& resdat )
 
     if ( pos >= length ) return ;
 
+    /* be */
+    if ( chpt[ pos ] == 'B' && chpt[ pos + 1 ] == 'E' ) {
+        pos += 3;
+        startpos = pos;
+        while ( chpt[ pos ] != '-' && pos++ < length );
+        resdat.be = rawStr.mid( startpos, pos - startpos );
+        pos++;
+        if ( pos < length && chpt[ pos ] == '#') {
+            startpos = pos;
+            while ( chpt[ pos ] == '#' && pos++ < length );
+            resdat.bepointmark = rawStr.mid( startpos, pos - startpos );
+        }
+    }
+
+    if ( pos >= length ) return ;
+
     /* host */
     if ( chpt[ pos ] == 'H' && chpt[ pos + 1 ] == 'O' ) {
         pos += 5;
@@ -1354,21 +1294,32 @@ void Kita::createTitleHTML( RESDAT& resdat, QString& titleHTML )
 
     /* date */
     if ( useTableTag ) titleHTML += "<td class=\"res_title_date\">";
-    titleHTML += m_colonstr + resdat.date + " ";
+    titleHTML += m_colonstr + resdat.date;
+    if ( useTableTag ) titleHTML += "</td>";
 
     /* ID */
     if ( resdat.id != QString::null ) {
 
         if ( useTableTag ) titleHTML += "<td class=\"res_title_id\">";
-        if ( resdat.id == "???" ) titleHTML += "ID:" + resdat.id;
-        else titleHTML += "<a href=\"#idpop" + resdat.id + "\">ID</a>" + ":" + resdat.id;
+        if ( resdat.id.contains( "???", true ) >= 1 ) titleHTML += " ID:" + resdat.id;
+        else titleHTML += " <a href=\"#idpop" + resdat.id + "\">ID</a>" + ":" + resdat.id;
+        if ( useTableTag ) titleHTML += "</td>";
+    }
+
+    /* BE */
+    if ( resdat.be != QString::null ) {
+
+        if ( useTableTag ) titleHTML += "<td class=\"res_title_be\">";
+        titleHTML += " <a href=\"#bepop" + resdat.be + "\">?" + resdat.bepointmark + "</a>";
+        if ( useTableTag ) titleHTML += "</td>";
     }
 
     /* host */
     if ( resdat.host != QString::null ) {
 
         if ( useTableTag ) titleHTML += "<td class=\"res_title_host\">";
-        titleHTML += "HOST:" + resdat.host;
+        titleHTML += " HOST:" + resdat.host;
+        if ( useTableTag ) titleHTML += "</td>";
     }
 
     if ( useTableTag ) titleHTML += "</tr></table>";
