@@ -26,8 +26,6 @@ public:
     static KitaThreadInfo* getInstance();
     static void setReadNum( const QString& url, int num );
     static int readNum( const QString& url );
-    static void setResNum( const QString& url, int num );
-    static int resNum( const QString& url );
     static void replace( const QString fromURL, const QString toURL );
     static void removeThreadInfo( const QString& url );
     friend QDataStream& operator<<( QDataStream& s, KitaThreadInfo& c );
